@@ -1,5 +1,5 @@
 /**
- * Copyright 2021 Sebastian Ramacher <sebastian@ramacher.at>
+ * Copyright 2021-2025 Sebastian Ramacher <sebastian@ramacher.at>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -23,6 +23,12 @@
 #ifndef WCWIDTH_COMPAT_H
 #define WCWIDTH_COMPAT_H
 
+#include <pyconfig.h>
+
+#if !defined(_WIN32) && !defined(_XOPEN_SOURCE)
+#define _XOPEN_SOURCE
+#endif
+
 #include <wchar.h>
 
 #if defined(USE_MK_WCWIDTH)
